@@ -5,7 +5,7 @@ import logging
 from notification.models import TaskHistory
 from dbaas_aclapi import helpers
 from dbaas_aclapi.acl_base_client import get_acl_client
-
+from acl_base_client import STATUS_PENDING
 
 logging.basicConfig()
 LOG = logging.getLogger("AclTask")
@@ -31,16 +31,18 @@ def replicate_acl_for(database, old_ip, new_ip, old_sa=None, new_sa=None):
         old_ip: new_ip
     }
 
-    if all([new_sa, old_sa]):
+    if old_sa:
         destinations.update({old_sa: new_sa})
 
     for acl in acl_clients:
         for d in destinations:
+
+            # old and new is the same
             if d == destinations[d]:
                 continue
 
             search = d
-            if is_ip(d):
+            if is_ip(search):
                 search = "%s/32" % search
 
             for rule in helpers.iter_on_acl_rules(acl, {"destination": search}):
@@ -53,6 +55,22 @@ def replicate_acl_for(database, old_ip, new_ip, old_sa=None, new_sa=None):
                     LOG.warn(error)
                     raise Exception(error)
 
+        # get and apply pending acls.
+        if acl.is_libera_3:
+            for dest in [new_ip, new_sa]:
+                if not dest:
+                    continue
+
+                search_destination = dest
+                if is_ip(search_destination):
+                    search_destination = "%s/32" % search_destination
+
+                for rule in helpers.iter_on_acl_rules(
+                 acl,
+                 {"destination": search_destination,
+                  "status": STATUS_PENDING}):
+                    acl.apply_acl(rule)
+
 
 def destroy_acl_for(database, ip):
     acl_client = get_acl_client(database.environment)
